-
-
-
-
-
-);
-
-module.exports = injectIntl(TopBanner);
diff --git a/src/views/splash/l10n.json b/src/views/splash/l10n.json
index 10651aeb7..dc1f2b368 100644
--- a/src/views/splash/l10n.json
+++ b/src/views/splash/l10n.json
@@ -41,16 +41,7 @@
"welcome.tryOut": "Try out starter projects",
"welcome.connect": "Connect with other Scratchers",
- "betabanner.title": "The Next Generation of Scratch",
- "betabanner.subtitle": "Scratch 3.0 is coming in January! Try the Beta version now.",
- "betabanner.callToAction": "Try it!",
-
- "hocbanner.title": "Get Creative with Coding!",
- "hocbanner.moreActivities": "See more activities",
- "hocbanner.gettingStarted": "Getting Started",
- "hocbanner.animationTalk": "Create Animations that Talk",
- "hocbanner.adventureGame": "Animate an Adventure Game",
- "hocbanner.name": "Animate a Name",
- "hocbanner.fly": "Make it Fly",
- "hocbanner.pong": "Pong Game"
+ "featureBanner.title": "The new Scratch is here!",
+ "featureBanner.subtitle": "not used",
+ "featureBanner.callToAction": "Start Creating"
}
diff --git a/static/images/beta/left-illustration.png b/static/images/beta/left-illustration.png
deleted file mode 100644
index 4c199d56e..000000000
Binary files a/static/images/beta/left-illustration.png and /dev/null differ
diff --git a/static/images/beta/right-illustration.png b/static/images/beta/right-illustration.png
deleted file mode 100644
index a472edf1a..000000000
Binary files a/static/images/beta/right-illustration.png and /dev/null differ
diff --git a/static/images/beta/bg-pattern.png b/static/images/feature/bg-pattern.png
similarity index 100%
rename from static/images/beta/bg-pattern.png
rename to static/images/feature/bg-pattern.png
diff --git a/static/svgs/feature/banner-notch.svg b/static/svgs/feature/banner-notch.svg
new file mode 100644
index 000000000..138cb96f0
--- /dev/null
+++ b/static/svgs/feature/banner-notch.svg
@@ -0,0 +1,9 @@
+
+
\ No newline at end of file
diff --git a/static/svgs/feature/create-icon.svg b/static/svgs/feature/create-icon.svg
new file mode 100644
index 000000000..b0f6eb23d
--- /dev/null
+++ b/static/svgs/feature/create-icon.svg
@@ -0,0 +1,17 @@
+
+
\ No newline at end of file
diff --git a/static/svgs/feature/illustration-left.svg b/static/svgs/feature/illustration-left.svg
new file mode 100644
index 000000000..1e8650893
--- /dev/null
+++ b/static/svgs/feature/illustration-left.svg
@@ -0,0 +1,35 @@
+
+
\ No newline at end of file
diff --git a/static/svgs/feature/illustration-right.svg b/static/svgs/feature/illustration-right.svg
new file mode 100644
index 000000000..b5b8ea256
--- /dev/null
+++ b/static/svgs/feature/illustration-right.svg
@@ -0,0 +1,203 @@
+
+
\ No newline at end of file
diff --git a/static/svgs/feature/tapping-block.svg b/static/svgs/feature/tapping-block.svg
new file mode 100644
index 000000000..6a9436803
--- /dev/null
+++ b/static/svgs/feature/tapping-block.svg
@@ -0,0 +1,32 @@
+
+
\ No newline at end of file
diff --git a/src/views/splash/presentation.jsx b/src/views/splash/presentation.jsx
index 8be069b6e..7a5a2e538 100644
--- a/src/views/splash/presentation.jsx
+++ b/src/views/splash/presentation.jsx
@@ -31,20 +31,13 @@ const LoveProjectMessage = require('./activity-rows/love-project.jsx');
const RemixProjectMessage = require('./activity-rows/remix-project.jsx');
const ShareProjectMessage = require('./activity-rows/share-project.jsx');
-// Beta Banner Components
-// const TopBanner = require('./beta/top-banner.jsx');
-const SmallTopBanner = require('./beta/small-top-banner.jsx');
-// const MiddleBanner = require('./beta/middle-banner.jsx');
+// Featured Banner Components
+const TopBanner = require('./feature/top-banner.jsx');
+const SmallTopBanner = require('./feature/small-top-banner.jsx');
+const MiddleBanner = require('./feature/middle-banner.jsx');
-const BETA_LAUNCH_TIME = 1533128400000; // August 1 at 9am ET
-const SMALL_BANNER_TIME = 1534942800000; // August 22 at 9am ET
-
-// Hour of Code Banner Components
-const TopBanner = require('./hoc/top-banner.jsx');
-const MiddleBanner = require('./hoc/middle-banner.jsx');
-
-const HOC_START_TIME = 1543813201000; // 12:01 am Dec 3rd
-const HOC_END_TIME = 1544806799000; // 11:59 Dec 14th
+// Scratch 3.0 Launch Banner
+const LAUNCH_END_TIME = 1547873999000;
require('./splash.scss');
@@ -238,7 +231,7 @@ class SplashPresentation extends React.Component { // eslint-disable-line react/
}
}
}
- renderHomepageRows () {
+ renderHomepageRows (showBanner) {
const rows = [
);
}
+
+ if (
+ this.props.sessionStatus === sessionActions.Status.FETCHED &&
+ Object.keys(this.props.user).length === 0 &&
+ showBanner // Show middle banner
+ ) {
+ rows.push(
+
+
+
+ );
+ }
if (this.props.featuredGlobal.scratch_design_studio &&
this.props.featuredGlobal.scratch_design_studio.length > 4) {
@@ -361,7 +369,10 @@ class SplashPresentation extends React.Component { // eslint-disable-line react/
return rows;
}
render () {
- const featured = this.renderHomepageRows();
+ const ShowTopBanner = Date.now() < LAUNCH_END_TIME;
+ const ShowMiddleBanner = false;
+ const ShowSmallTopBanner = false;
+ const featured = this.renderHomepageRows(ShowMiddleBanner);
const formatHTMLMessage = this.props.intl.formatHTMLMessage;
const formatNumber = this.props.intl.formatNumber;
@@ -433,27 +444,26 @@ class SplashPresentation extends React.Component { // eslint-disable-line react/
] : []}
{
this.props.sessionStatus === sessionActions.Status.FETCHED &&
- Object.keys(this.props.user).length === 0 && // Only show top banner if user is not logged in
- Date.now() >= HOC_START_TIME &&
- Date.now() < HOC_END_TIME &&
+ Object.keys(this.props.user).length === 0 && // if user is not logged in
+ ShowTopBanner &&
-
+
}
{
this.props.sessionStatus === sessionActions.Status.FETCHED &&
- Object.keys(this.props.user).length !== 0 && // Only show top banner if user is logged in
- Date.now() >= BETA_LAUNCH_TIME &&
+ Object.keys(this.props.user).length !== 0 && // if user is logged in
+ ShowTopBanner &&
- {Date.now() >= SMALL_BANNER_TIME ?
- : // Show small banner starting September 1 at 9am ET
-
+ {ShowSmallTopBanner ?
+ :
+
}
}
@@ -492,41 +502,17 @@ class SplashPresentation extends React.Component { // eslint-disable-line react/
minWidth={frameless.desktop}
>
{
- (Date.now() < HOC_START_TIME || // Hide intro if HoC banner is showing
- Date.now() > HOC_END_TIME) ?
- [
-
- ] :
- []
+ !ShowTopBanner && // show intro if not showing top banner
+
}
]) : []
}
- {featured.shift()}
- {featured.shift()}
-
- {
- this.props.sessionStatus === sessionActions.Status.FETCHED &&
- Object.keys(this.props.user).length !== 0 && // Only show if user is logged in
- Date.now() >= HOC_START_TIME && // Show middle banner on and after Dec 3
- Date.now() < HOC_END_TIME && // Hide middle banner after Dec 14
-
-
-
- }
-
-
{featured}
{this.props.isAdmin && (